Crate kcr_policy_karmada_io

Crate kcr_policy_karmada_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the policy.karmada.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

policy.karmada.io/v1alpha1

  • ClusterOverridePolicy
  • ClusterPropagationPolicy
  • FederatedResourceQuota
  • OverridePolicy
  • PropagationPolicy

Modules

v1alpha1